@@ -26,24 +26,19 @@ build_time_vars = {'ABIFLAGS': '',
  'CFLAGS': '-Wsign-compare -DNDEBUG',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
+ 'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
- 'CONFIGURE_CFLAGS_NODIST': '-O2 -march=x86-64 -mtune=generic -pipe '
-                            '-Wno-deprecated -Wno-deprecated-declarations '
-                            '-fno-plt -fstack-protector-strong '
-                            '-fstack-clash-protection -fcf-protection=full '
-                            '-fno-semantic-interposition -std=c11 -Wextra '
-                            '-Wno-unused-parameter '
+ 'CONFIGURE_CFLAGS_NODIST': '-O2 -march=x86-64 -mtune=generic -pipe -std=c11 '
+                            '-Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/usr/include/ncursesw',
  'CONFIGURE_LDFLAGS': '',
- 'CONFIGURE_LDFLAGS_NODIST': '-Wl,--hash-style=gnu -Wl,-O1 -Wl,--sort-common '
-                             '-Wl,--as-needed -Wl,-z,now -Wl,-z,relro '
-                             '-fno-semantic-interposition',
+ 'CONFIGURE_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed',
  'CONFIGURE_LDFLAGS_NOLTO': '',
  'CONFIG_ARGS': "'--prefix=/usr' '--build=x86_64-pc-linux-gnu' "
                 "'--host=x86_64-pc-linux-gnu' '--mandir=/usr/share/man' "
@@ -61,18 +56,13 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-system-ffi' '--with-system-libmpdec' "
                 "'--with-platlibdir=lib' '--with-pkg-config=yes' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
-                "'--without-assertions' '--enable-optimizations' "
+                "'--without-assertions' '--disable-optimizations' "
                 "'--with-readline=readline' '--without-valgrind' "
                 "'build_alias=x86_64-pc-linux-gnu' "
                 "'host_alias=x86_64-pc-linux-gnu' "
-                "'PKG_CONFIG=x86_64-pc-linux-gnu-pkg-config' 'CFLAGS=' "
-                "'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw' "
-                "'PROFILE_TASK=-m test -j24 --pgo-extended -u-network "
-                '--timeout 1200 -x test_gdb -x test_pretty_print -x '
-                'test_dtrace -x test_asyncio -x test_concurrent_futures -x '
-                'test_httpservers -x test_logging -x test_multiprocessing_fork '
-                '-x test_socket -x test_xmlrpc -x test_tools -x '
-                "test_distutils'",
+                "'PKG_CONFIG=x86_64-pc-linux-gnu-pkg-config' "
+                "'PKG_CONFIG_PATH=/opt/cuda/pkgconfig' 'CFLAGS=' 'LDFLAGS=' "
+                "'CPPFLAGS= -I/usr/include/ncursesw'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.11',
  'COREPYTHONPATH': '',
@@ -623,20 +613,22 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.11',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.11',
- 'INSTALL': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c',
- 'INSTALL_DATA': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c '
-                 '-m 644',
- 'INSTALL_PROGRAM': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
+ 'INSTALL': '/var/tmp/portage/._portage_reinstall_.3ygegrof/bin/ebuild-helpers/xattr/install '
+            '-c',
+ 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.3ygegrof/bin/ebuild-helpers/xattr/install '
+                 '-c -m 644',
+ 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.3ygegrof/bin/ebuild-helpers/xattr/install '
                     '-c',
- 'INSTALL_SCRIPT': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
+ 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.3ygegrof/bin/ebuild-helpers/xattr/install '
                    '-c',
- 'INSTALL_SHARED': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
+ 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.3ygegrof/bin/ebuild-helpers/xattr/install '
                    '-c -m 755',
  'INSTSONAME': 'libpython3.11.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'x86_64-pc-linux-gnu-g++ -shared',
  'LDFLAGS': '',
+ 'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.11.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'x86_64-pc-linux-gnu-gcc -shared',
@@ -646,14 +638,10 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDIR': '/usr/lib64',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -march=x86-64 -mtune=generic '
-                    '-pipe -Wno-deprecated -Wno-deprecated-declarations '
-                    '-fno-plt -fstack-protector-strong '
-                    '-fstack-clash-protection -fcf-protection=full '
-                    '-fno-semantic-interposition -std=c11 -Wextra '
-                    '-Wno-unused-parameter -Wno-missing-field-initializers '
-                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                    '-fvisibility=hidden -fprofile-use -fprofile-correction '
-                    '-I./Include/internal -I. -I./Include '
+                    '-pipe -std=c11 -Wextra -Wno-unused-parameter '
+                    '-Wno-missing-field-initializers -Wstrict-prototypes '
+                    '-Werror=implicit-function-declaration '
+                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                     '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
@@ -661,15 +649,12 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 -Wsign-compare '
-                    '-DNDEBUG -O2 -march=x86-64 -mtune=generic -pipe '
-                    '-Wno-deprecated -Wno-deprecated-declarations -fno-plt '
-                    '-fstack-protector-strong -fstack-clash-protection '
-                    '-fcf-protection=full -fno-semantic-interposition -std=c11 '
+                    '-DNDEBUG -O2 -march=x86-64 -mtune=generic -pipe -std=c11 '
                     '-Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
-                    '-Werror=implicit-function-declaration -fvisibility=hidden '
-                    '-fprofile-use -fprofile-correction -I./Include/internal '
-                    '-I. -I./Include -I/usr/include/ncursesw -fPIC -fPIC',
+                    '-Werror=implicit-function-declaration '
+                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                    '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
@@ -703,7 +688,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/share/man',
- 'MKDIR_P': '/bin/mkdir -p',
+ 'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'atexit  faulthandler  posix  _signal  _tracemalloc  '
                    '_codecs  _collections  errno  _io  itertools  _sre  '
                    '_thread  time  _weakref  _abc  _functools  _locale  '
@@ -903,9 +888,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__TESTINTERNALCAPI_STATE': 'yes',
  'MODULE__TESTMULTIPHASE_STATE': 'yes',
  'MODULE__THREAD_LDFLAGS': '',
- 'MODULE__TKINTER_CFLAGS': '-Wno-strict-prototypes -DWITH_APPINIT=1',
- 'MODULE__TKINTER_LDFLAGS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
- 'MODULE__TKINTER_STATE': 'yes',
+ 'MODULE__TKINTER_STATE': 'disabled',
  'MODULE__TRACEMALLOC_LDFLAGS': '',
  'MODULE__TYPING_STATE': 'yes',
  'MODULE__UUID_CFLAGS': '-I/usr/include/uuid',
@@ -941,11 +924,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test -j24 --pgo-extended -u-network --timeout 1200 -x '
-                 'test_gdb -x test_pretty_print -x test_dtrace -x test_asyncio '
-                 '-x test_concurrent_futures -x test_httpservers -x '
-                 'test_logging -x test_multiprocessing_fork -x test_socket -x '
-                 'test_xmlrpc -x test_tools -x test_distutils',
+ 'PROFILE_TASK': '-m test --pgo --timeout=1200',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -965,65 +944,44 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -march=x86-64 '
-                             '-mtune=generic -pipe -Wno-deprecated '
-                             '-Wno-deprecated-declarations -fno-plt '
-                             '-fstack-protector-strong '
-                             '-fstack-clash-protection -fcf-protection=full '
-                             '-fno-semantic-interposition -std=c11 -Wextra '
+                             '-mtune=generic -pipe -std=c11 -Wextra '
                              '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden -fprofile-use '
-                             '-fprofile-correction -I./Include/internal -I. '
+                             '-fvisibility=hidden  -I./Include/internal -I. '
                              '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wsign-compare -DNDEBUG',
- 'PY_CFLAGS_NODIST': '-O2 -march=x86-64 -mtune=generic -pipe -Wno-deprecated '
-                     '-Wno-deprecated-declarations -fno-plt '
-                     '-fstack-protector-strong -fstack-clash-protection '
-                     '-fcf-protection=full -fno-semantic-interposition '
-                     '-std=c11 -Wextra -Wno-unused-parameter '
-                     '-Wno-missing-field-initializers -Wstrict-prototypes '
+ 'PY_CFLAGS_NODIST': '-O2 -march=x86-64 -mtune=generic -pipe -std=c11 -Wextra '
+                     '-Wno-unused-parameter -Wno-missing-field-initializers '
+                     '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden -fprofile-use -fprofile-correction '
-                     '-I./Include/internal',
+                     '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -march=x86-64 -mtune=generic '
-                   '-pipe -Wno-deprecated -Wno-deprecated-declarations '
-                   '-fno-plt -fstack-protector-strong -fstack-clash-protection '
-                   '-fcf-protection=full -fno-semantic-interposition -std=c11 '
-                   '-Wextra -Wno-unused-parameter '
+                   '-pipe -std=c11 -Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden '
-                   '-fprofile-use -fprofile-correction -I./Include/internal '
-                   '-I. -I./Include -I/usr/include/ncursesw -fPIC '
-                   '-DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,--hash-style=gnu -Wl,-O1 -Wl,--sort-common '
-                    '-Wl,--as-needed -Wl,-z,now -Wl,-z,relro '
-                    '-fno-semantic-interposition',
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
+                   '-I./Include/internal -I. -I./Include '
+                   '-I/usr/include/ncursesw -fPIC -DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '',
- 'PY_LDFLAGS_NODIST': '-Wl,--hash-style=gnu -Wl,-O1 -Wl,--sort-common '
-                      '-Wl,--as-needed -Wl,-z,now -Wl,-z,relro '
-                      '-fno-semantic-interposition',
+ 'PY_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed',
  'PY_LDFLAGS_NOLTO': '',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -march=x86-64 '
-                        '-mtune=generic -pipe -Wno-deprecated '
-                        '-Wno-deprecated-declarations -fno-plt '
-                        '-fstack-protector-strong -fstack-clash-protection '
-                        '-fcf-protection=full -fno-semantic-interposition '
-                        '-std=c11 -Wextra -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers -Wstrict-prototypes '
+                        '-mtune=generic -pipe -std=c11 -Wextra '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden -fprofile-use '
-                        '-fprofile-correction -I./Include/internal -I. '
+                        '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -I/usr/include/ncursesw -fPIC',
  'PY_SUPPORT_TIER': 1,
  'Py_DEBUG': 0,
